==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/dd2/fontcache_8cpp.js <==
var fontcache_8cpp =
[
    [ "SpriteFontCache", "d6/d9d/classSpriteFontCache.html", "d6/d9d/classSpriteFontCache" ],
    [ "FreeTypeFontCache", "de/d54/classFreeTypeFontCache.html", "de/d54/classFreeTypeFontCache" ],
    [ "GlyphEntry", "d2/de5/structFreeTypeFontCache_1_1GlyphEntry.html", "d2/de5/structFreeTypeFontCache_1_1GlyphEntry" ],
    [ "CP___", "de/dd2/fontcache_8cpp.html#aaa50fc6b9367d8d19c67177713410889", null ],
    [ "CPSET", "de/dd2/fontcache_8cpp.html#a33d72c28fa3b42c0b72f0f4889cc6b7a", null ],
    [ "AllocateFont", "de/dd2/fontcache_8cpp.html#a96f8d0e7a53e4e5c5f59322ec5ca2b45", null ],
    [ "GetCharacterHeight", "de/dd2/fontcache_8cpp.html#abdc18f304b99c345a3fb9774371ec96b", null ],
    [ "GetFontAAState", "de/dd2/fontcache_8cpp.html#a835acc8d0efec0a28c9975ccd684c44f", null ],
    [ "InitFreeType", "de/dd2/fontcache_8cpp.html#ad4b027ee54e5f588893def5260a8975b", null ],
    [ "LoadFreeTypeFont", "de/dd2/fontcache_8cpp.html#a21e6b5aab9dee2bf989d0a1ac37b2001", null ],
    [ "UninitFreeType", "de/dd2/fontcache_8cpp.html#a25e4129a9d4088066dd431c090db1ec0", null ],
    [ "_default_font_ascender", "de/dd2/fontcache_8cpp.html#adcc08e57656dbfef8f2b2464a1a18e99", null ],
    [ "_default_font_height", "de/dd2/fontcache_8cpp.html#a55c1c75ce2d3af8474ff1b3e27806224", null ],
    [ "_freetype", "de/dd2/fontcache_8cpp.html#a7505e8ce4e2660a676461c80a9322c8e", null ],
    [ "_library", "de/dd2/fontcache_8cpp.html#ad1e6e5a6301234b402c79ab7a0056845", null ],
    [ "ASCII_LETTERSTART", "de/dd2/fontcache_8cpp.html#a63853629af1bac36375567d6b8dc40b7", null ],
    [ "FACE_COLOUR", "de/dd2/fontcache_8cpp.html#a076b03e4b492a81647dfd5eec7a746d1", null ],
    [ "MAX_FONT_SIZE", "de/dd2/fontcache_8cpp.html#a9b999d3e6ff92fe8558508737d91f506", null ],
    [ "SHADOW_COLOUR", "de/dd2/fontcache_8cpp.html#acf043237e55143a8a9ae42f94c01a1b8", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/dd2/fontcache_8cpp.js <==
var fontcache_8cpp =
[
    [ "SpriteFontCache", "d6/d9d/classSpriteFontCache.html", "d6/d9d/classSpriteFontCache" ],
    [ "TrueTypeFontCache", "d6/d42/classTrueTypeFontCache.html", "d6/d42/classTrueTypeFontCache" ],
    [ "GlyphEntry", "de/d10/structTrueTypeFontCache_1_1GlyphEntry.html", "de/d10/structTrueTypeFontCache_1_1GlyphEntry" ],
    [ "FreeTypeFontCache", "de/d54/classFreeTypeFontCache.html", "de/d54/classFreeTypeFontCache" ],
    [ "CP___", "de/dd2/fontcache_8cpp.html#aaa50fc6b9367d8d19c67177713410889", null ],
    [ "CPSET", "de/dd2/fontcache_8cpp.html#a33d72c28fa3b42c0b72f0f4889cc6b7a", null ],
    [ "AllocateFont", "de/dd2/fontcache_8cpp.html#a96f8d0e7a53e4e5c5f59322ec5ca2b45", null ],
    [ "GetCharacterHeight", "de/dd2/fontcache_8cpp.html#abdc18f304b99c345a3fb9774371ec96b", null ],
    [ "GetFontAAState", "de/dd2/fontcache_8cpp.html#a835acc8d0efec0a28c9975ccd684c44f", null ],
    [ "InitFreeType", "de/dd2/fontcache_8cpp.html#ad4b027ee54e5f588893def5260a8975b", null ],
    [ "LoadFreeTypeFont", "de/dd2/fontcache_8cpp.html#a21e6b5aab9dee2bf989d0a1ac37b2001", null ],
    [ "UninitFreeType", "de/dd2/fontcache_8cpp.html#a25e4129a9d4088066dd431c090db1ec0", null ],
    [ "_default_font_ascender", "de/dd2/fontcache_8cpp.html#adcc08e57656dbfef8f2b2464a1a18e99", null ],
    [ "_default_font_height", "de/dd2/fontcache_8cpp.html#a55c1c75ce2d3af8474ff1b3e27806224", null ],
    [ "_freetype", "de/dd2/fontcache_8cpp.html#a7505e8ce4e2660a676461c80a9322c8e", null ],
    [ "_library", "de/dd2/fontcache_8cpp.html#ad1e6e5a6301234b402c79ab7a0056845", null ],
    [ "ASCII_LETTERSTART", "de/dd2/fontcache_8cpp.html#a63853629af1bac36375567d6b8dc40b7", null ],
    [ "FACE_COLOUR", "de/dd2/fontcache_8cpp.html#a076b03e4b492a81647dfd5eec7a746d1", null ],
    [ "MAX_FONT_SIZE", "de/dd2/fontcache_8cpp.html#a9b999d3e6ff92fe8558508737d91f506", null ],
    [ "SHADOW_COLOUR", "de/dd2/fontcache_8cpp.html#acf043237e55143a8a9ae42f94c01a1b8", null ]
];
